<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Graphics

Windows Runtime (WinRT) APIs for for the `Windows.Graphics` namespace.

This package provides the `winrt.windows.graphics` module.
